@@ -2,9 +2,9 @@ from xml.etree import ElementTree
 
 import requests
 
-from quickbase_json.helpers import FileUpload
-from quickbase_json.qb_insert_update_response import QBInsertResponse
-from quickbase_json.qb_response import QBResponse, QBQueryResponse
+from src.quickbase_json.helpers import FileUpload
+from src.quickbase_json.qb_insert_update_response import QBInsertResponse
+from src.quickbase_json.qb_response import QBQueryResponse
 
 
 class QuickbaseJSONClient:
@@ -79,11 +79,9 @@ class QuickbaseJSONClient:
 
         r = requests.post('https://api.quickbase.com/v1/records', headers=self.headers, json=body)
 
-        res = QBInsertResponse()
+        res = QBInsertResponse().update(r)
 
-
-
-        return
+        return res
 
     def delete_records(self, table: str, where: str):
         """
@@ -125,7 +123,6 @@ class QuickbaseJSONClient:
 
         if self.debug:
             print(f'QJAC : easy_upload : file ---> \n{file}')
-            print(f'QJAC : easy_upload : data ---> \n{data}')
 
         return self.insert_update_records(table, data=data)
 
